@@ -7,7 +7,7 @@ use HTML::SocialMeta::Twitter;
 use HTML::SocialMeta::OpenGraph;
 use HTML::SocialMeta::Schema;
 
-our $VERSION = '0.2_1';
+our $VERSION = '0.2_2';
 
 has 'card_type' => ( isa => 'Str', is => 'rw', lazy => 1, default => q{} );
 has [
@@ -141,47 +141,6 @@ HTML::SocialMeta - Module to generate Social Media Meta Tags,
 
 Version 0.2
 
-=cut
-
-=head1 DESCRIPTION
-
-This module makes generates social meta tags.
-
-i.e  $social->create('summary') will generate:
-    
-    <meta itemprop="article" itemscope itemtype="http://schema.org/Article" />
-    <meta itemprop="name" content="You can have any title you wish here"/>
-    <meta itemprop="description" content="Description goes here may have to do a little validation"/>
-    <meta itemprop="image" content="www.urltoimage.com/blah.jpg"/>
-    <meta name="twitter:card" content="summary"/>
-    <meta name="twitter:site" content="@example_twitter"/>
-    <meta name="twitter:title" content="You can have any title you wish here"/>
-    <meta name="twitter:description" content="Description goes here may have to do a little validation"/>
-    <meta name="twitter:image" content="www.urltoimage.com/blah.jpg"/>
-    <meta property="og:type" content="thumbnail"/>
-    <meta property="og:title" content="You can have any title you wish here"/>
-    <meta property="og:description" content="Description goes here may have to do a little validation"/>
-    <meta property="og:url" content="www.someurl.com"/>
-    <meta property="og:image" content="www.urltoimage.com/blah.jpg"/>
-    <meta property="og:site_name" content="Example Site, anything"/>'
-
-It allows you to optimize sharing on several social media platforms such as Twitter, Facebook, Google+ 
-and Pinerest by defining exactly how titles, descriptions, images and more appear in social streams.
-
-It generates all the required META data for the following Providers:
-
-    * Twitter
-    * OpenGraph
-    * Schema.org
-
-This module currently allows you to generate the following meta cards:
-
-    $social->create()  $twitter->create_       $opengraph->create_  	$schema->create_
-    summary            summary                 thumbnail         	article
-    featured_image     summary_large_image     article            	offer 
-    player             player                  video              	video
-    app                app                     product             	software_aplication                 
-
 =head1 SYNOPSIS
 
     use HTML::SocialMeta;
@@ -220,25 +179,114 @@ This module currently allows you to generate the following meta cards:
     # template
     [% meta_tags | html %]
 
+=head1 DESCRIPTION
+
+This module generates social meta tags.
+
+i.e  $social->create('summary') will generate:
+    
+    <meta itemprop="article" itemscope itemtype="http://schema.org/Article" />
+    <meta itemprop="name" content="You can have any title you wish here"/>
+    <meta itemprop="description" content="Description goes here may have to do a little validation"/>
+    <meta itemprop="image" content="www.urltoimage.com/blah.jpg"/>
+    <meta name="twitter:card" content="summary"/>
+    <meta name="twitter:site" content="@example_twitter"/>
+    <meta name="twitter:title" content="You can have any title you wish here"/>
+    <meta name="twitter:description" content="Description goes here may have to do a little validation"/>
+    <meta name="twitter:image" content="www.urltoimage.com/blah.jpg"/>
+    <meta property="og:type" content="thumbnail"/>
+    <meta property="og:title" content="You can have any title you wish here"/>
+    <meta property="og:description" content="Description goes here may have to do a little validation"/>
+    <meta property="og:url" content="www.someurl.com"/>
+    <meta property="og:image" content="www.urltoimage.com/blah.jpg"/>
+    <meta property="og:site_name" content="Example Site, anything"/>'
+
+It allows you to optimize sharing on several social media platforms such as Twitter, Facebook, Google+ 
+and Pinerest by defining exactly how titles, descriptions, images and more appear in social streams.
+
+It generates all the required META data for the following Providers:
+
+    * Twitter
+    * OpenGraph
+    * Schema.org
+
+This module currently allows you to generate the following meta cards:
+
+    $social->create()  $twitter->create_       $opengraph->create_  	$schema->create_
+    summary            summary                 thumbnail         	article
+    featured_image     summary_large_image     article            	offer 
+    player             player                  video              	video
+    app                app                     product             	software_aplication                 
+
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 Constructor
 
 Returns an instance of this class. Requires C<$url> as an argument;
 
-    my $social = URL::Social->new(
-        card => '...',          # OPTIONAL - if you always want the same card type you can set it  	
-        site => '',	 	# The Twitter @username the card should be attributed to. Required for Twitter Card analytics. 
-        site_name => '',	# This is Used by Facebook, you can just set it as your organisations name.
-        title => '',		# The title of your content as it should appear in the card 
-        description => '',	# A description of the content in a maximum of 200 characters
-        image => '',	        # A URL to a unique image representing the content of the page
-        url => '',              # OPTIONAL OPENGRAPH - allows you to specify an alternative url link you want the reader to be redirected 
-        ... => '',
-        ... => '',
-    );
+=over
 
-=cut
+=item card
+
+OPTIONAL - if you always want the same card type you can set it 
+
+=item site
+
+The Twitter @username the card should be attributed to. Required for Twitter Card analytics. 
+
+=item site name
+
+This is Used by Facebook, you can just set it as your organisations name.
+
+=item title
+
+The title of your content as it should appear in the card 
+
+=item description
+
+A description of the content in a maximum of 200 characters
+
+=item image
+
+A URL to a unique image representing the content of the page
+
+=item url
+
+OPTIONAL OPENGRAPH - allows you to specify an alternative url link you want the reader to be redirected 
+
+=item player
+
+HTTPS URL to iframe player. This must be a HTTPS URL which does not generate active mixed content warnings in a web browser
+
+=item player_width
+
+Width of IFRAME specified in twitter:player in pixels
+
+=item player_height
+
+Height of IFRAME specified in twitter:player in pixels
+
+=item operating_system
+
+IOS or Android 
+
+=item app_country      
+
+UK/US ect
+
+=item app_name   
+
+The applications name
+
+=item app_id 
+
+String value, and should be the numeric representation of your app ID in the App Store (.i.e. 307234931)
+
+=item app_url 
+
+Application store url - direct link to App store page
+
+=back
 
 =head2 Summary Card
 
@@ -338,9 +386,9 @@ Fields Required:
     * title 
     * description 
     * image 
-    * player            # HTTPS URL to iframe player. This must be a HTTPS URL which does not generate active mixed content warnings in a web browser
-    * player_width      # Width of IFRAME specified in twitter:player in pixels
-    * player_height     # Height of IFRAME specified in twitter:player in pixels
+    * player                
+    * player_width           
+    * player_height     
 
 image to be displayed in place of the player on platforms that does not support iframes or inline players. You should make this image the same dimensions
 as your player. Images with fewer than 68,600 pixels (a 262 x 262 square image, or a 350 x 196 16:9 image) will cause the player card not to render. 
@@ -373,11 +421,11 @@ Fields Required
     * site
     * title
     * description
-    * operatingSystem   # IOS or ANDROID
-    * app_country       # UK/US ect
-    * app_name          # The applications name
-    * app_id            # String value, and should be the numeric representation of your app ID in the App Store (.i.e. 307234931)
-    * app_url           # Application store url - direct link to App store page
+    * operatingSystem   
+    * app_country      
+    * app_name        
+    * app_id           
+    * app_url           
 
 =cut
 
